@@ -48,11 +48,9 @@ def _get_value_for_key(key, obj, default):
     if is_indexable_but_not_string(obj):
         try:
             return obj[key]
-        except KeyError:
-            return default
-    if hasattr(obj, key):
-        return getattr(obj, key)
-    return default
+        except (IndexError, TypeError, KeyError):
+            pass
+    return getattr(obj, key, default)
 
 
 def to_marshallable_type(obj):
@@ -131,9 +129,10 @@ class Nested(Raw):
 
         return marshal(value, self.nested)
 
+
 class List(Raw):
-    def __init__(self, cls_or_instance):
-        super(List, self).__init__()
+    def __init__(self, cls_or_instance, **kwargs):
+        super(List, self).__init__(**kwargs)
         if isinstance(cls_or_instance, type):
             if not issubclass(cls_or_instance, Raw):
                 raise MarshallingException("The type of the list elements "
@@ -251,9 +250,10 @@ class DateTime(Raw):
 
 ZERO = MyDecimal()
 
+
 class Fixed(Raw):
-    def __init__(self, decimals=5):
-        super(Fixed, self).__init__()
+    def __init__(self, decimals=5, **kwargs):
+        super(Fixed, self).__init__(**kwargs)
         self.precision = MyDecimal('0.' + '0' * (decimals - 1) + '1')
 
     def format(self, value):
